/*
- 파일명: sstt-admin.js
- 위치: /assets/js/sstt-admin.js
- 기능: Scroll to Top 플러그인 관리자 설정 페이지 스크립트
- 작성일: 2025-03-12
*/

// ===================================
// 설정 페이지 미리보기
// ===================================
/* 설정 변경 시 미리보기 업데이트 */
jQuery(document).ready(function($) {
    // DOM이 완전히 로드된 후 실행
    $(window).on('load', function() {
        // 설정 요소
        var iconSelect = $('#sstt-icon');
        var positionSelect = $('#sstt-position');
        var colorInput = $('#sstt-color');
        var sizeInput = $('#sstt-size');
        var offsetInput = $('#sstt-offset');
        
        // 미리보기 요소
        var previewButton = $('#sstt-preview-button');
        var previewContainer = $('.sstt-preview-container');
        
        if (!previewButton.length) {
            console.log('미리보기 버튼 요소를 찾을 수 없습니다.');
            return;
        }
        
        console.log('미리보기 스크립트 초기화됨');
        
        // 아이콘 변경 시
        iconSelect.on('change', updatePreview);
        
        // 위치 변경 시
        positionSelect.on('change', updatePreview);
        
        // 색상 변경 시
        colorInput.on('input', updatePreview);
        
        // 크기 변경 시
        sizeInput.on('input', updatePreview);
        
        // 여백 변경 시
        offsetInput.on('input', updatePreview);
        
        // 미리보기 업데이트 함수
        function updatePreview() {
            // 현재 설정값 가져오기
            var currentIcon = iconSelect.val();
            var currentPosition = positionSelect.val();
            var currentColor = colorInput.val();
            var currentSize = sizeInput.val();
            var currentOffset = offsetInput.val();
            
            console.log('미리보기 업데이트: ', currentIcon, currentPosition, currentColor, currentSize, currentOffset);
            
            // 아이콘 업데이트
            previewButton.find('i').attr('class', 'bi ' + currentIcon);
            
            // 위치 업데이트
            if (currentPosition === 'left') {
                previewButton.css({
                    'left': currentOffset,
                    'right': 'auto'
                });
            } else {
                previewButton.css({
                    'right': currentOffset,
                    'left': 'auto'
                });
            }
            
            // 색상과 크기 업데이트
            previewButton.css({
                'color': currentColor,
                'font-size': currentSize
            });
        }
        
        // 초기 미리보기 설정
        updatePreview();
        
        // 미리보기 버튼 호버 효과
        previewButton.hover(
            function() {
                $(this).css('transform', 'translateY(-5px)');
                $(this).css('transition', 'transform 0.3s ease');
            },
            function() {
                $(this).css('transform', 'translateY(0)');
                $(this).css('transition', 'transform 0.3s ease');
            }
        );
    });
});