<?php
/*
- 파일명: settings-page.php
- 위치: /includes/settings-page.php
- 기능: Scroll to Top 플러그인 설정 페이지
- 작성일: 2025-03-12
*/

// 직접 접근 방지
if (!defined('ABSPATH')) {
    exit;
}

// 현재 저장된 옵션 가져오기
$options = get_option('sstt_options', array(
    'icon' => 'bi-arrow-up-circle-fill',
    'position' => 'right',
    'color' => '#0d6efd',
    'size' => '3rem',
    'offset' => '20px'
));
?>

<div class="wrap">
    <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
    
    <form method="post" action="options.php">
        <?php
        settings_fields('sstt_settings_group');
        do_settings_sections('sstt_settings_group');
        ?>
        
        <table class="form-table">
            <tr valign="top">
                <th scope="row">아이콘 선택</th>
                <td>
                    <div class="input-group">
                        <span class="input-group-text bg-white border-end-0">
                            <i class="bi bi-palette text-primary"></i>
                        </span>
                        <select name="sstt_options[icon]" class="form-control border-start-0">
                            <option value="bi-arrow-up-circle-fill" <?php selected($options['icon'], 'bi-arrow-up-circle-fill'); ?>>원형 화살표 (채워짐)</option>
                            <option value="bi-arrow-up-circle" <?php selected($options['icon'], 'bi-arrow-up-circle'); ?>>원형 화살표 (테두리)</option>
                            <option value="bi-arrow-up-square-fill" <?php selected($options['icon'], 'bi-arrow-up-square-fill'); ?>>사각형 화살표 (채워짐)</option>
                            <option value="bi-arrow-up-square" <?php selected($options['icon'], 'bi-arrow-up-square'); ?>>사각형 화살표 (테두리)</option>
                            <option value="bi-arrow-up" <?php selected($options['icon'], 'bi-arrow-up'); ?>>화살표만</option>
                            <option value="bi-chevron-up" <?php selected($options['icon'], 'bi-chevron-up'); ?>>쉐브론 화살표</option>
                        </select>
                    </div>
                    <p class="description">버튼에 사용할 아이콘을 선택하세요.</p>
                </td>
            </tr>
            
            <tr valign="top">
                <th scope="row">위치</th>
                <td>
                    <div class="input-group">
                        <span class="input-group-text bg-white border-end-0">
                            <i class="bi bi-geo-alt text-primary"></i>
                        </span>
                        <select name="sstt_options[position]" class="form-control border-start-0">
                            <option value="right" <?php selected($options['position'], 'right'); ?>>오른쪽</option>
                            <option value="left" <?php selected($options['position'], 'left'); ?>>왼쪽</option>
                        </select>
                    </div>
                    <p class="description">버튼이 표시될 위치를 선택하세요.</p>
                </td>
            </tr>
            
            <tr valign="top">
                <th scope="row">색상</th>
                <td>
                    <div class="input-group">
                        <span class="input-group-text bg-white border-end-0">
                            <i class="bi bi-palette text-primary"></i>
                        </span>
                        <input type="color" name="sstt_options[color]" value="<?php echo esc_attr($options['color']); ?>" class="form-control border-start-0" placeholder="버튼 색상">
                    </div>
                    <p class="description">버튼 색상을 선택하세요.</p>
                </td>
            </tr>
            
            <tr valign="top">
                <th scope="row">크기</th>
                <td>
                    <div class="input-group">
                        <span class="input-group-text bg-white border-end-0">
                            <i class="bi bi-arrows-fullscreen text-primary"></i>
                        </span>
                        <input type="text" name="sstt_options[size]" value="<?php echo esc_attr($options['size']); ?>" class="form-control border-start-0" placeholder="버튼 크기 (예: 3rem)">
                    </div>
                    <p class="description">버튼 크기를 CSS 단위로 입력하세요 (예: 3rem, 40px 등).</p>
                </td>
            </tr>
            
            <tr valign="top">
                <th scope="row">여백</th>
                <td>
                    <div class="input-group">
                        <span class="input-group-text bg-white border-end-0">
                            <i class="bi bi-border-width text-primary"></i>
                        </span>
                        <input type="text" name="sstt_options[offset]" value="<?php echo esc_attr($options['offset']); ?>" class="form-control border-start-0" placeholder="화면 가장자리로부터의 여백 (예: 20px)">
                    </div>
                    <p class="description">화면 가장자리로부터의 여백을 CSS 단위로 입력하세요.</p>
                </td>
            </tr>
        </table>
        
        <?php submit_button(); ?>
    </form>
    
    <div class="sstt-preview" style="margin-top: 30px;">
        <h2>미리보기</h2>
        <p>현재 설정된 스타일입니다:</p>
        <div style="position: relative; height: 100px; border: 1px solid #ddd; background: #f9f9f9;">
            <button style="position: absolute; bottom: 20px; <?php echo esc_attr($options['position']); ?>: <?php echo esc_attr($options['offset']); ?>; color: <?php echo esc_attr($options['color']); ?>; font-size: <?php echo esc_attr($options['size']); ?>; background: transparent; border: none;">
                <i class="bi <?php echo esc_attr($options['icon']); ?>"></i>
            </button>
        </div>
    </div>
</div>