<?php
/*
- 파일명: simple-scroll-to-top.php
- 위치: /
- 기능: 워드프레스에 Scroll to Top 버튼을 추가하는 플러그인
- 작성일: 2025-03-12
- 수정일: 2025-03-12
*/

/*
Plugin Name: Simple Scroll To Top
Plugin URI: https://url.kr/p/wp-plugin/simple-scroll-to-top
Description: 간단하게 웹사이트에 'Scroll to Top' 버튼을 추가해주는 플러그인입니다.
Version: 1.0
Author: 호텔천사
Author URI: https://webworks.co.kr
Text Domain: simple-scroll-to-top
Domain Path: /languages
*/

// ===================================
// 보안 설정
// ===================================
/* 직접 접근 방지 */
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly
}

// ===================================
// 전역 상수 정의
// ===================================
/* 플러그인 경로 및 URL 상수 정의 */
define('SSTT_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('SSTT_PLUGIN_URL', plugin_dir_url(__FILE__));
define('SSTT_PLUGIN_VERSION', '1.0.0');

// ===================================
// 스크립트 및 스타일 등록
// ===================================
/* 프론트엔드 스크립트 및 스타일시트 등록 */
function sstt_enqueue_scripts() {
    // Bootstrap Icons 등록
    wp_enqueue_style('bootstrap-icons', 'https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css', array(), '1.10.5');
    
    // 플러그인 CSS 등록
    wp_enqueue_style('sstt-style', SSTT_PLUGIN_URL . 'assets/css/sstt-style.css', array(), SSTT_PLUGIN_VERSION);
    
    // jQuery 및 플러그인 JS 등록
    wp_enqueue_script('jquery');
    wp_enqueue_script('sstt-script', SSTT_PLUGIN_URL . 'assets/js/sstt-script.js', array('jquery'), SSTT_PLUGIN_VERSION, true);
    
    // 인라인 스타일 추가 (옵션에 따른 버튼 스타일링)
    $options = get_option('sstt_options', array(
        'icon' => 'bi-arrow-up-circle-fill',
        'position' => 'right',
        'color' => '#0d6efd',
        'size' => '3rem',
        'offset' => '20px'
    ));
    
    $custom_css = "
        #sstt-button {
            color: {$options['color']};
            font-size: {$options['size']};
            " . ($options['position'] === 'left' ? 'left' : 'right') . ": {$options['offset']};
        }
    ";
    wp_add_inline_style('sstt-style', $custom_css);
}
add_action('wp_enqueue_scripts', 'sstt_enqueue_scripts');


/**
 * 플러그인 행 메타 정보 수정
 *
 * @param array $plugin_meta 플러그인 메타 정보 배열
 * @param string $plugin_file 플러그인 파일 경로
 * @return array 수정된 메타 정보 배열
 */
function sstt_plugin_row_meta($plugin_meta, $plugin_file) {
    // 현재 플러그인에 대해서만 적용
    if (plugin_basename(__FILE__) === $plugin_file) {
        // View details 링크 찾기 및 제거
        foreach ($plugin_meta as $key => $meta) {
            if (strpos($meta, 'plugin-install.php?tab=plugin-information') !== false) {
                unset($plugin_meta[$key]);
            }
        }
        
        // 설명서 링크 추가
		$plugin_meta[] = sprintf(
			'<a href="%s" target="_blank">%s</a>',
			'https://url.kr/p/wp-plugin/simple-scroll-to-top',
			__('플러그인 최신정보', 'simple-scroll-to-top')
		);
    }
    
    return $plugin_meta;
}
add_filter('plugin_row_meta', 'sstt_plugin_row_meta', 10, 2);


/* 관리자 스크립트 및 스타일 등록 */
function sstt_admin_enqueue_scripts($hook) {
    // 설정 페이지에서만 스크립트 로드
    if ($hook != 'toplevel_page_sstt-menu' && $hook != 'scroll-to-top_page_sstt-documentation') {
        return;
    }
    
    // Bootstrap Icons CSS 등록
    wp_enqueue_style('bootstrap-icons', 'https://cdn.jsdelivr.net/npm/bootstrap-icons@1.10.5/font/bootstrap-icons.css', array(), '1.10.5');
    
    // 관리자 스크립트 등록
    wp_enqueue_script('sstt-admin-script', SSTT_PLUGIN_URL . 'assets/js/sstt-admin.js', array('jquery'), SSTT_PLUGIN_VERSION, true);
    
    // 현재 설정 값을 스크립트에 전달
    $options = get_option('sstt_options', array(
        'icon' => 'bi-arrow-up-circle-fill',
        'position' => 'right',
        'color' => '#0d6efd',
        'size' => '3rem',
        'offset' => '20px'
    ));
    
    wp_localize_script('sstt-admin-script', 'ssttOptions', $options);
}
add_action('admin_enqueue_scripts', 'sstt_admin_enqueue_scripts');

// ===================================
// 버튼 출력
// ===================================
/* Scroll to Top 버튼 출력 */
function sstt_add_button() {
    $options = get_option('sstt_options', array(
        'icon' => 'bi-arrow-up-circle-fill',
        'position' => 'right'
    ));
    
    $position_class = ($options['position'] === 'left') ? 'sstt-left' : 'sstt-right';
    
    echo '<button id="sstt-button" class="' . esc_attr($position_class) . '">';
    echo '<i class="bi ' . esc_attr($options['icon']) . '"></i>';
    echo '</button>';
}
add_action('wp_footer', 'sstt_add_button');

// ===================================
// 관리자 설정
// ===================================
/* 관리자 메뉴 추가 */
function sstt_add_admin_menu() {
    // 메인 메뉴 추가
    add_menu_page(
        'Scroll to Top',        // 페이지 제목
        'Scroll to Top',        // 메뉴 제목
        'manage_options',       // 필요 권한
        'sstt-menu',            // 메뉴 슬러그 (상위 메뉴용)
        'sstt_settings_page',   // 콜백 함수 (메인 메뉴 클릭 시 표시할 페이지)
        'dashicons-arrow-up-alt2', // 아이콘
        100                     // 메뉴 위치
    );
    
    // 설정 서브메뉴 (기본 페이지로 동일)
    add_submenu_page(
        'sstt-menu',            // 부모 메뉴 슬러그
        'Scroll to Top 설정',    // 페이지 제목
        '설정',                  // 서브메뉴 제목
        'manage_options',       // 필요 권한
        'sstt-menu',            // 메뉴 슬러그 (부모와 동일하게 하면 기본 페이지가 됨)
        'sstt_settings_page'    // 콜백 함수
    );
    
    // 설명서 서브메뉴
    add_submenu_page(
        'sstt-menu',            // 부모 메뉴 슬러그
        'Scroll to Top 설명서',  // 페이지 제목
        '설명서',                // 서브메뉴 제목
        'manage_options',       // 필요 권한
        'sstt-documentation',   // 메뉴 슬러그
        'sstt_documentation_page' // 콜백 함수
    );
    
    // 설정 등록
    register_setting('sstt_settings_group', 'sstt_options');
}
add_action('admin_menu', 'sstt_add_admin_menu');

/* 설정 페이지 출력 */
function sstt_settings_page() {
    // 기존 설정 가져오기
    $options = get_option('sstt_options', array(
        'icon' => 'bi-arrow-up-circle-fill',
        'position' => 'right',
        'color' => '#0d6efd',
        'size' => '3rem',
        'offset' => '20px'
    ));
    ?>
    <div class="wrap">
        <h1><?php echo esc_html(get_admin_page_title()); ?></h1>
        
        <form method="post" action="options.php">
            <?php
            settings_fields('sstt_settings_group');
            do_settings_sections('sstt_settings_group');
            ?>
            
            <table class="form-table">
                <tr valign="top">
                    <th scope="row">아이콘 선택</th>
                    <td>
                        <div class="input-group">
                            <span class="input-group-text bg-white border-end-0">
                                <i class="bi bi-palette text-primary"></i>
                            </span>
                            <select name="sstt_options[icon]" id="sstt-icon" class="form-control border-start-0">
                                <option value="bi-arrow-up-circle-fill" <?php selected($options['icon'], 'bi-arrow-up-circle-fill'); ?>>원형 화살표 (채워짐)</option>
                                <option value="bi-arrow-up-circle" <?php selected($options['icon'], 'bi-arrow-up-circle'); ?>>원형 화살표 (테두리)</option>
                                <option value="bi-arrow-up-square-fill" <?php selected($options['icon'], 'bi-arrow-up-square-fill'); ?>>사각형 화살표 (채워짐)</option>
                                <option value="bi-arrow-up-square" <?php selected($options['icon'], 'bi-arrow-up-square'); ?>>사각형 화살표 (테두리)</option>
                                <option value="bi-arrow-up" <?php selected($options['icon'], 'bi-arrow-up'); ?>>화살표만</option>
                                <option value="bi-chevron-up" <?php selected($options['icon'], 'bi-chevron-up'); ?>>쉐브론 화살표</option>
                            </select>
                        </div>
                        <p class="description">버튼에 사용할 아이콘을 선택하세요.</p>
                    </td>
                </tr>
                
                <tr valign="top">
                    <th scope="row">위치</th>
                    <td>
                        <div class="input-group">
                            <span class="input-group-text bg-white border-end-0">
                                <i class="bi bi-geo-alt text-primary"></i>
                            </span>
                            <select name="sstt_options[position]" id="sstt-position" class="form-control border-start-0">
                                <option value="right" <?php selected($options['position'], 'right'); ?>>오른쪽</option>
                                <option value="left" <?php selected($options['position'], 'left'); ?>>왼쪽</option>
                            </select>
                        </div>
                        <p class="description">버튼이 표시될 위치를 선택하세요.</p>
                    </td>
                </tr>
                
                <tr valign="top">
                    <th scope="row">색상</th>
                    <td>
                        <div class="input-group">
                            <span class="input-group-text bg-white border-end-0">
                                <i class="bi bi-palette text-primary"></i>
                            </span>
                            <input type="color" name="sstt_options[color]" id="sstt-color" value="<?php echo esc_attr($options['color']); ?>" class="form-control border-start-0" placeholder="버튼 색상">
                        </div>
                        <p class="description">버튼 색상을 선택하세요.</p>
                    </td>
                </tr>
                
                <tr valign="top">
                    <th scope="row">크기</th>
                    <td>
                        <div class="input-group">
                            <span class="input-group-text bg-white border-end-0">
                                <i class="bi bi-arrows-fullscreen text-primary"></i>
                            </span>
                            <input type="text" name="sstt_options[size]" id="sstt-size" value="<?php echo esc_attr($options['size']); ?>" class="form-control border-start-0" placeholder="버튼 크기 (예: 3rem)">
                        </div>
                        <p class="description">버튼 크기를 CSS 단위로 입력하세요 (예: 3rem, 40px 등).</p>
                    </td>
                </tr>
                
                <tr valign="top">
                    <th scope="row">여백</th>
                    <td>
                        <div class="input-group">
                            <span class="input-group-text bg-white border-end-0">
                                <i class="bi bi-border-width text-primary"></i>
                            </span>
                            <input type="text" name="sstt_options[offset]" id="sstt-offset" value="<?php echo esc_attr($options['offset']); ?>" class="form-control border-start-0" placeholder="화면 가장자리로부터의 여백 (예: 20px)">
                        </div>
                        <p class="description">화면 가장자리로부터의 여백을 CSS 단위로 입력하세요.</p>
                    </td>
                </tr>
            </table>
            
            <?php submit_button(); ?>
        </form>
        
        <div class="sstt-preview-section" style="margin-top: 30px;">
            <h2>미리보기</h2>
            <p>현재 설정된 스타일입니다:</p>
            <div class="sstt-preview-container" style="position: relative; height: 150px; border: 1px solid #ddd; background: #f9f9f9; overflow: hidden; border-radius: 4px;">
                <button id="sstt-preview-button" style="position: absolute; bottom: 20px; <?php echo esc_attr($options['position']); ?>: <?php echo esc_attr($options['offset']); ?>; color: <?php echo esc_attr($options['color']); ?>; font-size: <?php echo esc_attr($options['size']); ?>; background: transparent; border: none; cursor: pointer; transition: transform 0.3s ease;">
                    <i class="bi <?php echo esc_attr($options['icon']); ?>"></i>
                </button>
            </div>
        </div>
    </div>
    <?php
}

/* 설명서 페이지 출력 */
function sstt_documentation_page() {
    // readme.txt 파일 경로
    $readme_file = SSTT_PLUGIN_DIR . 'readme.txt';
    
    // 파일 존재 확인
    if (file_exists($readme_file)) {
        // 파일 내용 읽기
        $readme_content = file_get_contents($readme_file);
        
        // 내용 줄별로 분리
        $lines = explode("\n", $readme_content);
        
        // HTML 출력 시작
        $html = '<div class="sstt-documentation">';
        
        $in_pre = false;
        $current_section = '';
        
        foreach ($lines as $key => $line) {
            $line = trim($line);
            
            // 빈 줄 처리
            if (empty($line)) {
                if (!$in_pre) {
                    $html .= '<br>';
                } else {
                    $html .= "\n";
                }
                continue;
            }
            
            // 파일 구조 트리 시작 부분 체크
            if (strpos($line, 'simple-scroll-to-top/') !== false) {
                $html .= '<pre class="sstt-pre-code">';
                $in_pre = true;
            }
            
            // pre 코드 블록 안에 있는 경우
            if ($in_pre) {
                $html .= htmlspecialchars($line) . "\n";
                
                // pre 코드 블록 종료 체크 - 다음 섹션 시작으로 판단
                if (!empty($lines[$key + 1]) && strpos($lines[$key + 1], '사용 방법:') !== false) {
                    $html .= '</pre>';
                    $in_pre = false;
                }
                continue;
            }
            
            // 섹션 제목 체크 (예: '설명:', '기능:' 등)
            if (preg_match('/^([^:]+):$/', $line, $matches)) {
                $current_section = $matches[1];
                $html .= '<h2 class="sstt-section-title">' . esc_html($current_section) . '</h2>';
                continue;
            }
            
            // 목록 항목 체크 (대시로 시작하는 경우)
            if (strpos($line, '- ') === 0) {
                if (strpos($html, '<ul class="sstt-list">') === false) {
                    $html .= '<ul class="sstt-list">';
                }
                $html .= '<li>' . esc_html(substr($line, 2)) . '</li>';
                
                // 다음 줄이 대시로 시작하지 않으면 목록 닫기
                if (!isset($lines[$key + 1]) || strpos($lines[$key + 1], '- ') !== 0) {
                    $html .= '</ul>';
                }
                continue;
            }
            
            // 숫자 목록 항목 체크
            if (preg_match('/^(\d+)\. (.*)$/', $line, $matches)) {
                if (strpos($html, '<ol class="sstt-ordered-list">') === false) {
                    $html .= '<ol class="sstt-ordered-list">';
                }
                $html .= '<li>' . esc_html($matches[2]) . '</li>';
                
                // 다음 줄이 숫자로 시작하지 않으면 목록 닫기
                if (!isset($lines[$key + 1]) || !preg_match('/^(\d+)\. (.*)$/', $lines[$key + 1])) {
                    $html .= '</ol>';
                }
                continue;
            }
            
            // 일반 텍스트 처리
            $html .= '<p class="sstt-text">' . esc_html($line) . '</p>';
        }
        
        $html .= '</div>';
    } else {
        $html = '<p>readme.txt 파일을 찾을 수 없습니다.</p>';
    }
    ?>
    <div class="wrap">
        <h1>Scroll to Top 플러그인 설명서</h1>
        
        <div class="card">
            <?php echo $html; ?>
        </div>
        
        <div class="card" style="margin-top: 20px;">
            <h2>설정 바로가기</h2>
            <p><a href="<?php echo admin_url('admin.php?page=sstt-menu'); ?>" class="button button-primary">설정 페이지로 이동</a></p>
        </div>
    </div>
    <style>
        .card {
            background: #fff;
            border: 1px solid #ccd0d4;
            border-radius: 4px;
            padding: 20px 25px;
            box-shadow: 0 1px 1px rgba(0,0,0,0.04);
            margin-bottom: 20px;
            width: 100%;
            max-width: 100%;
            box-sizing: border-box;
        }
        .sstt-documentation {
            font-size: 14px;
            line-height: 1.6;
            width: 100%;
            word-wrap: break-word;
            overflow-wrap: break-word;
        }
        .sstt-section-title {
            margin-top: 20px;
            margin-bottom: 10px;
            font-size: 18px;
            font-weight: 600;
            color: #23282d;
            border-bottom: 1px solid #eee;
            padding-bottom: 5px;
        }
        .sstt-text {
            margin: 8px 0;
        }
        .sstt-list, .sstt-ordered-list {
            margin-left: 20px;
            margin-bottom: 15px;
        }
        .sstt-list li, .sstt-ordered-list li {
            margin-bottom: 5px;
        }
        .sstt-pre-code {
            background-color: #f5f5f5;
            padding: 15px;
            border-radius: 4px;
            font-family: monospace;
            overflow-x: auto;
            white-space: pre-wrap;
            word-wrap: break-word;
            margin: 15px 0;
            border: 1px solid #e0e0e0;
            max-width: 100%;
        }
    </style>
    <?php
}

// ===================================
// 플러그인 활성화
// ===================================
/* 플러그인 활성화 시 기본 옵션 설정 */
function sstt_activate() {
    if (!get_option('sstt_options')) {
        update_option('sstt_options', array(
            'icon' => 'bi-arrow-up-circle-fill',
            'position' => 'right',
            'color' => '#0d6efd',
            'size' => '3rem',
            'offset' => '20px'
        ));
    }
}
register_activation_hook(__FILE__, 'sstt_activate');